package betterquesting.network.handlers;

import betterquesting.api.events.DatabaseEvent;
import betterquesting.api.network.QuestingPacket;
import betterquesting.api.questing.party.IParty;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.utils.Tuple2;
import betterquesting.core.BetterQuesting;
import betterquesting.network.PacketSender;
import betterquesting.network.PacketTypeRegistry;
import betterquesting.questing.party.PartyManager;
import cpw.mods.fml.common.FMLCommonHandler;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;
import javax.annotation.Nullable;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.server.MinecraftServer;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.common.MinecraftForge;

/* loaded from: betterquesting_network_handlers.jar:betterquesting/network/handlers/NetPartySync.class */
public class NetPartySync {
    private static final ResourceLocation ID_NAME = new ResourceLocation("betterquesting:party_sync");

    public static void registerHandler() {
        PacketTypeRegistry.INSTANCE.registerServerHandler(ID_NAME, NetPartySync::onServer);
        if (BetterQuesting.proxy.isClient()) {
            PacketTypeRegistry.INSTANCE.registerClientHandler(ID_NAME, NetPartySync::onClient);
        }
    }

    public static void quickSync(int partyID) {
        MinecraftServer server = FMLCommonHandler.instance().getMinecraftServerInstance();
        IParty party = (IParty) PartyManager.INSTANCE.getValue(partyID);
        if (server == null || party == null) {
            return;
        }
        List<EntityPlayerMP> players = new ArrayList<>();
        for (UUID uuid : party.getMembers()) {
            EntityPlayerMP p = null;
            for (Object o : server.func_71203_ab().field_72404_b) {
                if (((EntityPlayerMP) o).func_146103_bH().getId().equals(uuid)) {
                    p = (EntityPlayerMP) o;
                }
            }
            if (p != null) {
                players.add(p);
            }
        }
        sendSync((EntityPlayerMP[]) players.toArray(new EntityPlayerMP[0]), new int[]{partyID});
    }

    public static void sendSync(@Nullable EntityPlayerMP[] players, @Nullable int[] partyIDs) {
        if (partyIDs == null || partyIDs.length > 0) {
            if (players == null || players.length > 0) {
                NBTTagList dataList = new NBTTagList();
                List<DBEntry<IParty>> partySubset = partyIDs == null ? PartyManager.INSTANCE.getEntries() : PartyManager.INSTANCE.bulkLookup(partyIDs);
                for (DBEntry<IParty> party : partySubset) {
                    NBTTagCompound entry = new NBTTagCompound();
                    entry.func_74768_a("partyID", party.getID());
                    entry.func_74782_a("config", ((IParty) party.getValue()).writeToNBT(new NBTTagCompound()));
                    dataList.func_74742_a(entry);
                }
                NBTTagCompound payload = new NBTTagCompound();
                payload.func_74782_a("data", dataList);
                payload.func_74757_a("merge", partyIDs != null);
                if (players == null) {
                    PacketSender.INSTANCE.sendToAll(new QuestingPacket(ID_NAME, payload));
                } else {
                    PacketSender.INSTANCE.sendToPlayers(new QuestingPacket(ID_NAME, payload), players);
                }
            }
        }
    }

    @SideOnly(Side.CLIENT)
    public static void requestSync(@Nullable int[] partyIDs) {
        NBTTagCompound payload = new NBTTagCompound();
        if (partyIDs != null) {
            payload.func_74783_a("partyIDs", partyIDs);
        }
        PacketSender.INSTANCE.sendToServer(new QuestingPacket(ID_NAME, payload));
    }

    private static void onServer(Tuple2<NBTTagCompound, EntityPlayerMP> message) {
        NBTTagCompound payload = (NBTTagCompound) message.func_76341_a();
        int[] reqIDs = !payload.func_74764_b("partyIDs") ? null : payload.func_74759_k("partyIDs");
        sendSync(new EntityPlayerMP[]{(EntityPlayerMP) message.func_76340_b()}, reqIDs);
    }

    @SideOnly(Side.CLIENT)
    private static void onClient(NBTTagCompound message) {
        NBTTagList data = message.func_150295_c("data", 10);
        if (!message.func_74767_n("merge")) {
            PartyManager.INSTANCE.reset();
        }
        for (int i = 0; i < data.func_74745_c(); i++) {
            NBTTagCompound tag = data.func_150305_b(i);
            if (tag.func_150297_b("partyID", 99)) {
                int partyID = tag.func_74762_e("partyID");
                IParty party = (IParty) PartyManager.INSTANCE.getValue(partyID);
                if (party == null) {
                    party = PartyManager.INSTANCE.createNew(partyID);
                }
                party.readFromNBT(tag.func_74775_l("config"));
            }
        }
        MinecraftForge.EVENT_BUS.post(new DatabaseEvent.Update(DatabaseEvent.DBType.PARTY));
    }
}
